/* extractTOF.cpp
 *
 * ROOT MACRO
 * 
 * Extract the TOF from the ROOT output
 *
 */

{
	gROOT->Reset();
	
#include "Riostream.h"
#include "math.h"
	
	Int_t i, nevents;	//index i and number of event
	Float_t         globalPosX1, globalPosX2, globalPosY1, globalPosY2, globalPosZ1, globalPosZ2;
	Float_t         sourcePosX1, sourcePosX2, sourcePosY1, sourcePosY2, sourcePosZ1, sourcePosZ2;
	Double_t        time1, time2, deltaTime;
	Int_t			comptonPhantom1, comptonCrystal1, RayleighPhantom1, RayleighCrystal1;
	Int_t			comptonPhantom2, comptonCrystal2, RayleighPhantom2, RayleighCrystal2;
	ofstream fout;	//output file
	fout.open("./tof.txt");	//store the TOF in the file lor.txt
	
	TFile *f = new TFile("./output.root");	//replace "output.root" by your root file
	TTree *t = f->Get("Coincidences");	//this is where you tell it what "tree" you want to access: coincidences, singles, or I don't know what else
	
	//here, you get the address of all the info you want (but you don't get the actual values yet)
	//Coincidences->SetBranchStatus("*",0);
	Coincidences->SetBranchAddress("globalPosX1",&globalPosX1);
	Coincidences->SetBranchAddress("globalPosX2",&globalPosX2);
	Coincidences->SetBranchAddress("globalPosY1",&globalPosY1);
	Coincidences->SetBranchAddress("globalPosY2",&globalPosY2);
	Coincidences->SetBranchAddress("globalPosZ1",&globalPosZ1);
	Coincidences->SetBranchAddress("globalPosZ2",&globalPosZ2);
	Coincidences->SetBranchAddress("sourcePosX1",&sourcePosX1);
	Coincidences->SetBranchAddress("sourcePosX2",&sourcePosX2);
	Coincidences->SetBranchAddress("sourcePosY1",&sourcePosY1);
	Coincidences->SetBranchAddress("sourcePosY2",&sourcePosY2);
	Coincidences->SetBranchAddress("sourcePosZ1",&sourcePosZ1);
	Coincidences->SetBranchAddress("sourcePosZ2",&sourcePosZ2);
	Coincidences->SetBranchAddress("time1",&time1);
	Coincidences->SetBranchAddress("time2",&time2);
	Coincidences->SetBranchAddress("comptonPhantom1",&comptonPhantom1);
	Coincidences->SetBranchAddress("comptonCrystal1",&comptonCrystal1);
	Coincidences->SetBranchAddress("RayleighPhantom1",&RayleighPhantom1);
	Coincidences->SetBranchAddress("RayleighCrystal1",RayleighCrystal1);
	Coincidences->SetBranchAddress("comptonPhantom2",&comptonPhantom2);
	Coincidences->SetBranchAddress("comptonCrystal2",&comptonCrystal2);
	Coincidences->SetBranchAddress("RayleighPhantom2",&RayleighPhantom2);
	Coincidences->SetBranchAddress("RayleighCrystal2",RayleighCrystal2);

	/*NOTE: the "name" of the info you want (e.g. "globalPosX1", or "time1") can be found in the root file;
	 1) Open the root file in root: root yourRootFile.root
	 2) Type: TBrowser t
	 3) Navigate to your root file and open it
	 4) Go into the Coincidences directory ("tree", in the root lingo)
	 5) All the "leaves" you see are the information stored for each coincidence; this is where the "globalPosX1" and "time1" come from
	 */
	
	nevents = t->GetEntries();	//I need the total number of events in order to loop adequately over all events
	cout << "Number of events = " << nevents << "\n";
	
	Int_t numScatter = 0;
	//it's in this loop that you actually extract all the info that you just told root you wanted
	for (i = 0; i < nevents; i++) {
		t->GetEntry(i);	//here, you're accessing event #i; all your variables from above now get the values desired
		
		//calculate the TOF
		deltaTime = time2 - time1;

		//get the TOF time in picoseconds
		deltaTime /= (1.e-12);
		
		if ( comptonPhantom1 > 0 || comptonPhantom2 > 0 ) {
			++numScatter;
		}
		
		//calculate the centre of the Line Of Response
		double xCentre, yCentre, zCentre;
		xCentre = (globalPosX1 + globalPosX2)/2;
		yCentre = (globalPosY1 + globalPosY2)/2;
		zCentre = (globalPosZ1 + globalPosZ2)/2;
		
		//calculate the direction vector of the LOR
		double dx, dy, dz;
		dx = globalPosX1 - globalPosX2;
		dy = globalPosY1 - globalPosY2;
		dz = globalPosZ1 - globalPosZ2;
		
		double norm = sqrt(dx*dx + dy*dy + dz*dz);
		dx /= norm;
		dy /= norm;
		dz /= norm;
		
		//calculate the annihilation point along the LOR
		double c = 299792458.;
		double annihilationDist = deltaTime*(1.e-12)*c*1000. / 2;
		double annihilationPtX = xCentre + (annihilationDist * dx);
		double annihilationPtY = yCentre + (annihilationDist * dy);
		double annihilationPtZ = zCentre + (annihilationDist * dz);
		
		
		//write these values to a .txt file
		/*
		fout << globalPosX1 << "\t" << globalPosY1 << "\t" << globalPosZ1 << "\t";
		fout << globalPosX2 << "\t" << globalPosY2 << "\t" << globalPosZ2 << "\t";
		fout << comptonPhantom1 << "\t" << RayleighPhantom1 << "\t";
		fout << comptonPhantom2 << "\t" << RayleighPhantom2 << "\t";
		fout << time1 << "\t" << time2 << "\t";
		fout << deltaTime << "\t" << deltaTimeBinned << "\t";
		fout << annihilationPtX << "\t" << annihilationPtY << "\t" << annihilationPtZ << "\t";
		fout << annihilationPtXBin << "\t" << annihilationPtYBin << "\t" << annihilationPtZBin << "\n";
		 */
		fout << annihilationPtX << "\t" << annihilationPtY << "\t" << annihilationPtZ << "\t";
		fout << deltaTime << "\n";

	}
	
		cout << "Scatter fraction = " << (double)numScatter / nevents << "\n";
		
	fout.close();
}